@@ -3,13 +3,14 @@ from __future__ import annotations
 from datetime import datetime
 from typing import TYPE_CHECKING, Optional
 
-from .member import Member
 from .route import Route
 
 if TYPE_CHECKING:
     from .team import Team
     from .state import ConnectionState
     from .channel import Channel
+    from .member import Member
+
 
 # noinspection PyProtectedMember
 from .types.message import (
@@ -18,8 +19,7 @@ from .types.message import (
     JoinMessage as JoinMessagePayload,
     PurposeMessage as PurposeMessagePayload,
     PreviousMessage as PreviousMessagePayload,
-    DeletedMessage as DeletedMessagePayload,
-    ArchivedMessage as ArchivedMessagePayload
+    DeletedMessage as DeletedMessagePayload
 )
 
 __all__ = (
@@ -31,7 +31,7 @@ __all__ = (
 
 
 class Message:
-    """This function is a constructor for the Message class. It takes in two parameters, state and data. The state
+    """This class is a constructor for the Message class. It takes in two parameters, state and data. The state
     parameter is a ConnectionState object, and the data parameter is a MessagePayload object. The function then sets the
     state, team_id, id, author, channel_id, and created_at attributes of the Message object
 
@@ -57,6 +57,7 @@ class Message:
         self.channel_id = data.get("channel")
         self.content = data.get("text", "")
         self.created_at: datetime = datetime.fromtimestamp(float(self.id))
+        self.scheduled_message_id: Optional[str] = None
         self.__edited: Optional[_Edited] = data.get("edited")
         self.__edited_ts: str = self.__edited.get("ts") if self.__edited else self.id
         self.__edited_user: Optional[Member] = self.state.members.get(
@@ -88,19 +89,19 @@ class Message:
             Message author.
 
         """
-        print(self.user)
         return self.state.members.get(self.user)
 
     @property
     def team(self) -> Team:
         """Message team.
+
         Returns
         -------
-        :class:`~Team`
+        :class:`Team`
             Message team.
 
         """
-        return self.state.teams[self.team_id]
+        return self.state.teams.get(self.team_id)
 
     async def edit(self, text: str, is_bot: bool = True):
         """|coro|
@@ -164,6 +165,28 @@ class Message:
         rtn.pop("ok")
         return DeletedMessage(self.state, rtn)
 
+    async def reply(self, text: str):
+        """
+
+        Parameters
+        ----------
+        text: :class:`str`
+
+        Returns
+        -------
+        :class:`Message`
+        """
+        param = {
+            "channel": self.channel_id,
+            "thread_ts": self.id,
+            "text": str(text)
+        }
+        rtn = await self.state.http.send_message(
+            Route("POST", "chat.postMessage", self.state.http.bot_token),
+            data=param
+        )
+        return Message(self.state, rtn["message"])
+
 
 class JoinMessage(Message):
     """This function is a constructor for the JoinMessage class. It takes in a ConnectionState and a JoinMessagePayload as
