@@ -11,17 +11,6 @@ messagesubtype = Literal[
     "message_deleted"
 ]
 
-__all__ = (
-    "_Edited",
-    "PreviousMessage",
-    "DeletedMessage",
-    "Attatchment",
-    "Message",
-    "JoinMessage",
-    "PurposeMessage",
-    "ArchivedMessage"
-)
-
 
 class ArchivedMessage(TypedDict):
     type: str
@@ -121,14 +110,13 @@ class Message(TypedDict):
     # subtype: str
     event_ts: str
     channel_type: str
-    channel: str
-    event_ts: str
-    channel_type: str
+    # channel: str
+    # event_ts: str
+    # channel_type: str
     # blocks:
     edited: Optional[_Edited]
 
 
-
 class JoinMessage(Message):
     subtype: str
 
